@@ -164,7 +164,10 @@ class LfpDevignetter(LfpMicroLenses):
 
         M = np.mean(self.cfg.calibs[self.cfg.ptc_mean])
         lp_kernel = misc.create_gauss_kernel(length=M)
-        bw_img = rgb2gry(self._wht_img) if len(self._wht_img.shape) == 3 else self._wht_img
+        if len(self._wht_img.shape) == 3:
+            bw_img = rgb2gry(self._wht_img)[..., 0] if self._wht_img.shape[2] == 3 else self._wht_img[..., 0]
+        else:
+            bw_img = self._wht_img
         flt_img = convolve2d(bw_img, lp_kernel, 'same')
 
         self.sta.progress(100, self.cfg.params[self.cfg.opt_prnt])
